@@ -39,7 +39,7 @@ def get_price(csv=False):
             os.chdir('output')
 
         df = pd.DataFrame(data)
-        df.to_excel('output.csv', index=False)
+        df.to_csv('output.csv', index=False)
         print('File Created')
 
     return data
